@@ -17,7 +17,7 @@ using namespace ting;
 
 
 void Client::SendLoginResult(bool success){
-	Array<byte> p(2);
+	Array<ting::byte> p(2);
 
 	p[0] = 0;
 	p[1] = success ? 0 : 1;
@@ -46,7 +46,7 @@ void Client::SendPlayingPlayer(const std::string& playerNickname){
 
 
 void Client::SendStopListening(){
-	Array<byte> p(1);
+	Array<ting::byte> p(1);
 
 	p[0] = 0x02;
 
@@ -56,7 +56,7 @@ void Client::SendStopListening(){
 
 
 void Client::SendRegisterResult(ERegisterRes result){
-	Array<byte> p(2);
+	Array<ting::byte> p(2);
 
 	p[0] = 0x04; //register response
 
